@@ -245,7 +245,7 @@ using the mask image in the cache for that path.")
       ],
       "pre-Yosemite": [
         ["16x16",       12,   8,  1], ["16x16@2x",    26,  14,  2],
-        ["32x32",       26,  14,  2], ["32x32@2x",    52,  60,  4],
+        ["32x32",       26,  14,  2], ["32x32@2x",    52,  30,  4],
 
         ["128x128",    103,  60,  9], ["128x128@2x", 206, 121, 18],
         ["256x256",    206, 121, 18], ["256x256@2x", 412, 242, 36],
@@ -269,6 +269,13 @@ using the mask image in the cache for that path.")
       iconset_folder
     ])
 
+    # Make sure seticon is executable.
+    subprocess.check_call([
+      "chmod",
+      "+x",
+      seticon_path
+    ])
+
     # Set icon  for target.
     subprocess.check_call([
       seticon_path,
